@@ -22,12 +22,15 @@
 
 from __future__ import print_function
 
+
 import base64
 import json
 import six
 import sys
 import yaml
 
+from textwrap import dedent
+
 from hpecp.k8s_cluster import (
     K8sCluster,
     K8sClusterStatus,
@@ -48,6 +51,7 @@ class K8sClusterProxy(base.BaseProxy):
             "dashboard_url",
             "dashboard_token",
             "delete",
+            "examples",
             "get",
             "get_available_addons",
             "get_installed_addons",
@@ -157,6 +161,18 @@ class K8sClusterProxy(base.BaseProxy):
         else:
             print(base64.b64decode(token.encode()).decode("utf-8"))
 
+    def examples(self):
+        """Show examples for working with k8sclusters."""
+        print(
+            dedent(
+                """\
+                # retrieve id of k8s cluster with name 'c1'
+                $ hpecp k8scluster list --query "[?label.name == 'c1'] | [0] | [_links.self.href]" --output text
+                /api/v2/k8scluster/1
+                """  # noqa:  E501
+            )
+        )
+
     @base.intercept_exception
     def k8smanifest(self):
         """Retrieve the k8smanifest."""
